@@ -1,4 +1,4 @@
 library(drfit)
 data(XY)
 rXY <- drfit(XY,logit=TRUE,weibull=TRUE,chooseone=FALSE)
-rXY
+print(rXY,digits=5)
